Index: wp-login.php
===================================================================
--- wp-login.php	(revision 18794)
+++ wp-login.php	(working copy)
@@ -232,7 +232,7 @@
 	$message = apply_filters('retrieve_password_message', $message, $key);
 
 	if ( $message && !wp_mail($user_email, $title, $message) )
-		wp_die( __('The e-mail could not be sent.') . "<br />\n" . __('Possible reason: your host may have disabled the mail() function...') );
+		wp_die( __('The e-mail could not be sent.') . "<br />\n" . __('Possible reason: your host may have disabled the mail() function&#8230;') );
 
 	return true;
 }
@@ -324,7 +324,7 @@
 	$user_pass = wp_generate_password( 12, false);
 	$user_id = wp_create_user( $sanitized_user_login, $user_pass, $user_email );
 	if ( ! $user_id ) {
-		$errors->add( 'registerfail', sprintf( __( '<strong>ERROR</strong>: Couldn&#8217;t register you... please contact the <a href="mailto:%s">webmaster</a> !' ), get_option( 'admin_email' ) ) );
+		$errors->add( 'registerfail', sprintf( __( '<strong>ERROR</strong>: Couldn&#8217;t register you&#8230; please contact the <a href="mailto:%s">webmaster</a> !' ), get_option( 'admin_email' ) ) );
 		return $errors;
 	}
 
Index: wp-includes/class-wp-xmlrpc-server.php
===================================================================
--- wp-includes/class-wp-xmlrpc-server.php	(revision 18794)
+++ wp-includes/class-wp-xmlrpc-server.php	(working copy)
@@ -3545,7 +3545,7 @@
 
 		$pagelinkedfrom = str_replace('&', '&amp;', $pagelinkedfrom);
 
-		$context = '[...] ' . esc_html( $excerpt ) . ' [...]';
+		$context = '[&#8230;] ' . esc_html( $excerpt ) . ' [&#8230;]';
 		$pagelinkedfrom = $wpdb->escape( $pagelinkedfrom );
 
 		$comment_post_ID = (int) $post_ID;
Index: wp-includes/pluggable.php
===================================================================
--- wp-includes/pluggable.php	(revision 18794)
+++ wp-includes/pluggable.php	(working copy)
@@ -1026,7 +1026,7 @@
 		/* translators: 1: comment author, 2: author IP, 3: author domain */
 		$notify_message .= sprintf( __('Website: %1$s (IP: %2$s , %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
 		$notify_message .= sprintf( __('URL    : %s'), $comment->comment_author_url ) . "\r\n";
-		$notify_message .= __('Excerpt: ') . "\r\n" . sprintf('[...] %s [...]', $comment->comment_content ) . "\r\n\r\n";
+		$notify_message .= __('Excerpt: ') . "\r\n" . sprintf('[&#8230;] %s [&#8230;]', $comment->comment_content ) . "\r\n\r\n";
 		$notify_message .= __('You can see all pingbacks on this post here: ') . "\r\n";
 		/* translators: 1: blog name, 2: post title */
 		$subject = sprintf( __('[%1$s] Pingback: "%2$s"'), $blogname, $post->post_title );
Index: wp-includes/script-loader.php
===================================================================
--- wp-includes/script-loader.php	(revision 18794)
+++ wp-includes/script-loader.php	(working copy)
@@ -206,7 +206,7 @@
 		'file_cancelled' => __('File canceled.'),
 		'upload_stopped' => __('Upload stopped.'),
 		'dismiss' => __('Dismiss'),
-		'crunching' => __('Crunching&hellip;'),
+		'crunching' => __('Crunching&#8230;'),
 		'deleted' => __('moved to the trash.'),
 		'error_uploading' => __('&#8220;%s&#8221; has failed to upload due to an error')
 	);
Index: wp-trackback.php
===================================================================
--- wp-trackback.php	(revision 18794)
+++ wp-trackback.php	(working copy)
@@ -87,8 +87,8 @@
 	if ( !pings_open($tb_id) )
 		trackback_response(1, 'Sorry, trackbacks are closed for this item.');
 
-	$title =  wp_html_excerpt( $title, 250 ).'...';
-	$excerpt = wp_html_excerpt( $excerpt, 252 ).'...';
+	$title =  wp_html_excerpt( $title, 250 ).'&#8230;';
+	$excerpt = wp_html_excerpt( $excerpt, 252 ).'&#8230;';
 
 	$comment_post_ID = (int) $tb_id;
 	$comment_author = $blog_name;
@@ -108,4 +108,4 @@
 	do_action('trackback_post', $wpdb->insert_id);
 	trackback_response(0);
 }
-?>
\ No newline at end of file
+?>
Index: wp-admin/nav-menus.php
===================================================================
--- wp-admin/nav-menus.php	(revision 18794)
+++ wp-admin/nav-menus.php	(working copy)
@@ -418,7 +418,7 @@
 foreach( (array) $nav_menus as $key => $_nav_menu ) {
 	$_nav_menu->truncated_name = trim( wp_html_excerpt( $_nav_menu->name, 40 ) );
 	if ( $_nav_menu->truncated_name != $_nav_menu->name )
-		$_nav_menu->truncated_name .= '&hellip;';
+		$_nav_menu->truncated_name .= '&#8230;';
 
 	$nav_menus[$key]->truncated_name = $_nav_menu->truncated_name;
 }
Index: wp-admin/setup-config.php
===================================================================
--- wp-admin/setup-config.php	(revision 18794)
+++ wp-admin/setup-config.php	(working copy)
@@ -105,7 +105,7 @@
 	<li>Table prefix (if you want to run more than one WordPress in a single database) </li>
 </ol>
 <p><strong>If for any reason this automatic file creation doesn't work, don't worry. All this does is fill in the database information to a configuration file. You may also simply open <code>wp-config-sample.php</code> in a text editor, fill in your information, and save it as <code>wp-config.php</code>. </strong></p>
-<p>In all likelihood, these items were supplied to you by your Web Host. If you do not have this information, then you will need to contact them before you can continue. If you&#8217;re all ready&hellip;</p>
+<p>In all likelihood, these items were supplied to you by your Web Host. If you do not have this information, then you will need to contact them before you can continue. If you&#8217;re all ready&#8230;</p>
 
 <p class="step"><a href="setup-config.php?step=1<?php if ( isset( $_GET['noapi'] ) ) echo '&amp;noapi'; ?>" class="button">Let&#8217;s go!</a></p>
 <?php
@@ -263,7 +263,7 @@
 		chmod(ABSPATH . 'wp-config.php', 0666);
 		display_header();
 ?>
-<p>All right sparky! You've made it through this part of the installation. WordPress can now communicate with your database. If you are ready, time now to&hellip;</p>
+<p>All right sparky! You've made it through this part of the installation. WordPress can now communicate with your database. If you are ready, time now to&#8230;</p>
 
 <p class="step"><a href="install.php" class="button">Run the install</a></p>
 <?php
Index: wp-admin/plugin-editor.php
===================================================================
--- wp-admin/plugin-editor.php	(revision 18794)
+++ wp-admin/plugin-editor.php	(working copy)
@@ -133,7 +133,7 @@
 
 		if ( !empty($functions) ) {
 			$docs_select = '<select name="docs-list" id="docs-list">';
-			$docs_select .= '<option value="">' . __( 'Function Name&hellip;' ) . '</option>';
+			$docs_select .= '<option value="">' . __( 'Function Name&#8230;' ) . '</option>';
 			foreach ( $functions as $function) {
 				$docs_select .= '<option value="' . esc_attr( $function ) . '">' . esc_html( $function ) . '()</option>';
 			}

Index: wp-includes/default-widgets.php
===================================================================
--- wp-includes/default-widgets.php	(revision 18794)
+++ wp-includes/default-widgets.php	(working copy)
@@ -826,11 +826,11 @@
 		$desc = str_replace( array("\n", "\r"), ' ', esc_attr( strip_tags( @html_entity_decode( $item->get_description(), ENT_QUOTES, get_option('blog_charset') ) ) ) );
 		$desc = wp_html_excerpt( $desc, 360 );
 
 		// Append ellipsis. Change existing [...] to [&hellip;].
 		if ( '[...]' == substr( $desc, -5 ) )
-			$desc = substr( $desc, 0, -5 ) . '[&hellip;]';
-		elseif ( '[&hellip;]' != substr( $desc, -10 ) )
-			$desc .= ' [&hellip;]';
+			$desc = substr( $desc, 0, -5 ) . '[&#8230;]';
+		elseif ( '[&#8230;]' != substr( $desc, -9 ) )
+			$desc .= ' [&#8230;]';
 
 		$desc = esc_html( $desc );
 
@@ -826,11 +826,11 @@
 		$desc = wp_html_excerpt( $desc, 360 );
 
-		// Append ellipsis. Change existing [...] to [&hellip;].
+		// Append ellipsis. Change existing [...] to [&#8230;].
 		if ( '[...]' == substr( $desc, -5 ) )
Index: wp-includes/formatting.php
===================================================================
--- wp-includes/formatting.php	(revision 18794)
+++ wp-includes/formatting.php	(working copy)
@@ -1843,11 +1843,11 @@
  * Generates an excerpt from the content, if needed.
  *
  * The excerpt word amount will be 55 words and if the amount is greater than
  * that, then the string ' [...]' will be appended to the excerpt. If the string
  * is less than 55 words, then the content will be returned as is.
  *
  * The 55 word limit can be modified by plugins/themes using the excerpt_length filter
- * The ' [...]' string can be modified by plugins/themes using the excerpt_more filter
+ * The ' [&#8230;]' string can be modified by plugins/themes using the excerpt_more filter
  *
  * @since 1.5.0
  *
@@ -1864,7 +1864,7 @@
 		$text = apply_filters('the_content', $text);
 		$text = str_replace(']]>', ']]&gt;', $text);
 		$excerpt_length = apply_filters('excerpt_length', 55);
-		$excerpt_more = apply_filters('excerpt_more', ' ' . '[...]');
+		$excerpt_more = apply_filters('excerpt_more', ' ' . '[&#8230;]');
 		$text = wp_trim_words( $text, $excerpt_length, $excerpt_more );
 	}
 	return apply_filters('wp_trim_excerpt', $text, $raw_excerpt);
@@ -1877,12 +1877,12 @@
  *
  * @param string $text Text to trim.
  * @param int $num_words Number of words. Default 55.
  * @param string $more What to append if $text needs to be trimmed. Default '&hellip;'.
  * @return string Trimmed text.
  */
 function wp_trim_words( $text, $num_words = 55, $more = null ) {
 	if ( null === $more )
-		$more = __( '&hellip;' );
+		$more = __( '&#8230;' );
 	$original_text = $text;
 	$text = wp_strip_all_tags( $text );
 	$words_array = preg_split( "/[\n\r\t ]+/", $text, $num_words + 1, PREG_SPLIT_NO_EMPTY );
@@ -1843,11 +1843,11 @@
  *
  * The excerpt word amount will be 55 words and if the amount is greater than
- * that, then the string ' [...]' will be appended to the excerpt. If the string
+ * that, then the string ' [&#8230;]' ([...]) will be appended to the excerpt. If the string
  * is less than 55 words, then the content will be returned as is.
  *
@@ -1877,12 +1877,12 @@
  * @param string $text Text to trim.
  * @param int $num_words Number of words. Default 55.
- * @param string $more What to append if $text needs to be trimmed. Default '&hellip;'.
+ * @param string $more What to append if $text needs to be trimmed. Default '&#8230;'.
  * @return string Trimmed text.
  */